/*
   _===_ _           _                  ______ _     _             _ _ _
  |  ___| |         | |                 | ___ (_)   | |           (_) | |
  | |__ | | ___  ___| |_ _ __ ___ ______| |_/ /_  __| | ___  _   _ _| | | ___ _   _ _ __
  |  __|| |/ _ \/ __| __| '__/ _ \______| ___ \ |/ _` |/ _ \| | | | | | |/ _ \ | | | '__|
  | |___| |  __/ (__| |_| | | (_) |     | |_/ / | (_| | (_) | |_| | | | |  __/ |_| | |
  \____/|_|\___|\___|\__|_|  \___/      \____/|_|\__,_|\___/ \__,_|_|_|_|\___|\__,_|_|

  Essai DAC/ADC/I2C du Seeeduino XIAO
  Utilise un Module LCD 16x2 classique (HD44780) équipé d'une plaquette d'interface I2C basée sur le mux i2c PCF8574.
  Électro-Bidouilleur, Octobre 2021
 */
 
#include <Wire.h>   // La librairie I2C pour le Seeeduino XIAO
/*    Définition des broches du I2C dans la librairie wire.h: 
       SDA -> A4
       SCL -> A5    
       
#include <LiquidCrystal_PCF8574.h>
/* Cette librairie a été installée à partir du menu "Sketch/Include Librairy/Manage Librairies..."
   Elle se nomme LiquidCrystal_PCF8574. Plus d'info au http://www.mathertel.de/Arduino/LiquidCrystal_PCF8574.aspx 
   Par Mathias Hertel. */

#define addr_LCD 0x27                 // L'adresse I2C du LCD

LiquidCrystal_PCF8574 lcd(addr_LCD);  // Configurer l'adresse I2C du LCD à 0x27

int adcPin = A1;    // définition de la broche d'entrée de l'ADC
int dacPin = A0;    // définition de la broche de sortie du DAC
int adcValue = 0;   // variable de sauvegarde de la lecture de l'ADC
int dacValue = 0;   // variable de sauvegarde de la valeur écrite au DAC

// Fonction d'initialisation
void setup() 
{
  // Initialisation du port i2c du LCD
  Wire.begin();             // Initialisation de la communication I2C avec le LCD

  // Définir et initialiser le LCD
  lcd.begin(16, 2);         // Définir et initialiser le LCD comme ayant 16 colonnes et 2 lignes
  lcd.setBacklight(255);    // Allumer le rétro-éclairage

  analogWriteResolution(10);    // Fixer la résolution DAC à 10 bits
  analogReadResolution(10);    // Fixer la résolution ADC à 10 bits
}

// Fonction de Boucle Perpetuelle
void loop()
{ 
  for (dacValue = 0; dacValue <= 1023; dacValue += 10)  // Boucle d'incrémentation du DAC
  {
    analogWrite(dacPin, dacValue);    // Écrire une nouvelle valeur de DAC
    adcValue = analogRead(adcPin);    // Lire la valeur d'ADC correspondante

    // Affichage des valeurs DAC et ADC 
    lcd.home();                  // positionner le curseur à la première case
    lcd.clear();                 // Effacer l'écran
    lcd.print("DAC: ");          // Afficher le texte entre apostrophes
    lcd.print(dacValue);         // Afficher le texte  
    lcd.setCursor(0, 1);         // positionner le curseur
    lcd.print("ADC: ");          // Afficher le texte entre apostrophes
    lcd.print(adcValue);         // Afficher le texte  
    delay(400);                  // faire une pause sur chaque valeur
   }
}
